==> pointpos_api-0.0.13.tar.gz: lib/api/ingredient_category_api.dart <==
import 'package:jaguar_retrofit/annotations/annotations.dart';
import 'package:jaguar_retrofit/jaguar_retrofit.dart';
import 'package:jaguar_serializer/jaguar_serializer.dart';
import 'package:jaguar_mimetype/jaguar_mimetype.dart';
import 'dart:async';

import 'package:pointpos_api/model/exception.dart';
import 'package:pointpos_api/model/ingredient_category.dart';

part 'ingredient_category_api.jretro.dart';

@GenApiClient()
class IngredientCategoryApi extends ApiClient with _$IngredientCategoryApiClient {
    final Route base;
    final Map<String, CodecRepo> converters;
    final Duration timeout;

    IngredientCategoryApi({this.base, this.converters, this.timeout = const Duration(minutes: 2)});

    /// Create Ingredientcategory
    ///
    /// Create Ingredientcategory
    @PostReq(path: "/ingredient-category", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<IngredientCategory> createIngredientcategory(
        
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey
            ,
             @AsJson() IngredientCategory body
        ) {
        return super.createIngredientcategory(
        
        authorization, 
        
        xAPIKey

        ,
        body
        ).timeout(timeout);
    }

    /// Delete Ingredientcategory By ID
    ///
    /// Delete Ingredientcategory By ID
    @DeleteReq(path: "/ingredient-category/:id", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<void> deleteIngredientcategoryByID(
            @PathParam("id") num id
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey
        ) {
        return super.deleteIngredientcategoryByID(
        id
        ,
        authorization, 
        
        xAPIKey

        ).timeout(timeout);
    }

    /// Get Ingredientcategory List
    ///
    /// Get Ingredientcategory  List
    @GetReq(path: "/ingredient-category", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<List<IngredientCategory>> findIngredientcategory(
        
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey
        ,
            @QueryParam("limit") num limit, 
        
            @QueryParam("offset") num offset, 
        
            @QueryParam("sort") String sort, 
        
            @QueryParam("direction") String direction, 
        
            @QueryParam("filter") List<String> filter
        ) {
        return super.findIngredientcategory(
        
        authorization, 
        
        xAPIKey
        ,
        limit, 
        
        offset, 
        
        sort, 
        
        direction, 
        
        filter

        ).timeout(timeout);
    }

    /// Get Ingredientcategory By ID
    ///
    /// Get Ingredientcategory By ID
    @GetReq(path: "/ingredient-category/:id", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<IngredientCategory> getIngredientcategoryByID(
            @PathParam("id") num id
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey
        ) {
        return super.getIngredientcategoryByID(
        id
        ,
        authorization, 
        
        xAPIKey

        ).timeout(timeout);
    }

    /// Update Ingredientcategory By ID
    ///
    /// Update [object Object] By ID
    @PutReq(path: "/ingredient-category/:id", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<IngredientCategory> updateIngredientcategoryByID(
            @PathParam("id") num id
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey
            ,
             @AsJson() IngredientCategory body
        ) {
        return super.updateIngredientcategoryByID(
        id
        ,
        authorization, 
        
        xAPIKey

        ,
        body
        ).timeout(timeout);
    }


}

==> pointpos_api-0.0.16.tar.gz: lib/api/ingredient_category_api.dart <==
import 'package:jaguar_retrofit/annotations/annotations.dart';
import 'package:jaguar_retrofit/jaguar_retrofit.dart';
import 'package:jaguar_serializer/jaguar_serializer.dart';
import 'package:jaguar_mimetype/jaguar_mimetype.dart';
import 'dart:async';

import 'package:pointpos_api/model/exception.dart';
import 'package:pointpos_api/model/ingredient_category.dart';

part 'ingredient_category_api.jretro.dart';

@GenApiClient()
class IngredientCategoryApi extends ApiClient with _$IngredientCategoryApiClient {
    final Route base;
    final Map<String, CodecRepo> converters;
    final Duration timeout;

    IngredientCategoryApi({this.base, this.converters, this.timeout = const Duration(minutes: 2)});

    /// Create Ingredientcategory
    ///
    /// Create Ingredientcategory
    @PostReq(path: "/ingredient-category", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<IngredientCategory> createIngredientcategory(
        
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
            ,
             @AsJson() IngredientCategory body
        ) {
        return super.createIngredientcategory(
        
        authorization, 
        
        xAPIKey, 
        
        xPin

        ,
        body
        ).timeout(timeout);
    }

    /// Delete Ingredientcategory By ID
    ///
    /// Delete Ingredientcategory By ID
    @DeleteReq(path: "/ingredient-category/:id", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<void> deleteIngredientcategoryByID(
            @PathParam("id") num id
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
        ) {
        return super.deleteIngredientcategoryByID(
        id
        ,
        authorization, 
        
        xAPIKey, 
        
        xPin

        ).timeout(timeout);
    }

    /// Get Ingredientcategory List
    ///
    /// Get Ingredientcategory  List
    @GetReq(path: "/ingredient-category", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<List<IngredientCategory>> findIngredientcategory(
        
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
        ,
            @QueryParam("limit") num limit, 
        
            @QueryParam("offset") num offset, 
        
            @QueryParam("sort") String sort, 
        
            @QueryParam("direction") String direction, 
        
            @QueryParam("filter") List<String> filter
        ) {
        return super.findIngredientcategory(
        
        authorization, 
        
        xAPIKey, 
        
        xPin
        ,
        limit, 
        
        offset, 
        
        sort, 
        
        direction, 
        
        filter

        ).timeout(timeout);
    }

    /// Get Ingredientcategory By ID
    ///
    /// Get Ingredientcategory By ID
    @GetReq(path: "/ingredient-category/:id", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<IngredientCategory> getIngredientcategoryByID(
            @PathParam("id") num id
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
        ) {
        return super.getIngredientcategoryByID(
        id
        ,
        authorization, 
        
        xAPIKey, 
        
        xPin

        ).timeout(timeout);
    }

    /// Update Ingredientcategory By ID
    ///
    /// Update [object Object] By ID
    @PutReq(path: "/ingredient-category/:id", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<IngredientCategory> updateIngredientcategoryByID(
            @PathParam("id") num id
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
            ,
             @AsJson() IngredientCategory body
        ) {
        return super.updateIngredientcategoryByID(
        id
        ,
        authorization, 
        
        xAPIKey, 
        
        xPin

        ,
        body
        ).timeout(timeout);
    }


}
